@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::DMARC;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20180912'; # VERSION
+our $VERSION = '2.20180927'; # VERSION
 
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -385,6 +385,7 @@ sub _process_dmarc_for {
 
     # Run the Validator
     my $dmarc_result = $dmarc->validate();
+    my $is_subdomain = $dmarc->is_subdomain();
 
     # ToDo Set multiple dmarc_result objects here
     # this will become relevant when the BIMI handler
@@ -404,6 +405,8 @@ sub _process_dmarc_for {
     $self->dbgout( 'DMARCDisposition', $dmarc_disposition, LOG_INFO );
     my $dmarc_disposition_evaluated = $dmarc_disposition;
 
+    $self->dbgout( 'DMARCSubdomain', $is_subdomain ? 'yes' : 'no', LOG_INFO );
+
     my $dmarc_policy = eval{ $dmarc_result->published()->p(); };
     $self->handle_exception( $@ );
     # If we didn't get a result, set to none.
@@ -411,7 +414,7 @@ sub _process_dmarc_for {
     my $dmarc_sub_policy = eval{ $dmarc_result->published()->sp(); };
     $self->handle_exception( $@ );
     # If we didn't get a result, set to none.
-    $dmarc_sub_policy = 'none' if ! $dmarc_sub_policy;
+    $dmarc_sub_policy = 'default' if ! $dmarc_sub_policy;
     $self->dbgout( 'DMARCPolicy', "$dmarc_policy $dmarc_sub_policy", LOG_INFO );
 
     my $policy_override;
@@ -479,7 +482,7 @@ sub _process_dmarc_for {
             push @comments, $self->format_header_entry( 'p', $dmarc_policy );
             $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'policy.published-domain-policy' )->safe_set_value( $dmarc_policy ) );
         }
-        if ( $dmarc_sub_policy ) {
+        if ( $dmarc_sub_policy ne 'default' ) {
             push @comments, $self->format_header_entry( 'sp', $dmarc_sub_policy );
             $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'policy.published-subdomain-policy' )->safe_set_value( $dmarc_sub_policy ) );
         }
@@ -507,6 +510,8 @@ sub _process_dmarc_for {
             $header->add_child( Mail::AuthenticationResults::Header::Comment->new()->safe_set_value( join( ',', @comments ) ) );
         }
 
+        my $policy_used = ( $is_subdomain && $dmarc_sub_policy ne 'default' ) ? 'sp' : 'p';
+        $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'policy.policy-from' )->safe_set_value( $policy_used ) );
 
         $header->add_child( Mail::AuthenticationResults::Header::SubEntry->new()->set_key( 'header.from' )->safe_set_value( $header_domain ) );
         $self->_add_dmarc_header( $header );
@@ -521,6 +526,7 @@ sub _process_dmarc_for {
         'is_whitelisted'   => ( $is_whitelisted ? '1' : '0'),
         'arc_aware_result' => $arc_aware_result,
         'used_arc'         => ( $arc_aware_result ? '1' : '0' ),
+        'is_subdomain'     => ( $is_subdomain ? '1' : '0' ),
     };
     $self->metric_count( 'dmarc_total', $metric_data );
 
@@ -860,7 +866,7 @@ Mail::Milter::Authentication::Handler::DMARC
 
 =head1 VERSION
 
-version 2.20180912
+version 2.20180927
 
 =head1 DESCRIPTION
 
